@@ -8,12 +8,12 @@ package Device::LSM303DLHC;
 #
 # This file is part of Device-LSM303DLHC
 #
-# This software is copyright (c) 2013 by Shantanu Bhadoria.
+# This software is copyright (c) 2015 by Shantanu Bhadoria.
 #
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -72,7 +72,7 @@ Device::LSM303DLHC - I2C interface to LSM303DLHC 3 axis magnetometer(compass) an
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 ATTRIBUTES
 
@@ -102,7 +102,7 @@ This is a object of L<Device::Accelerometer::LSM303DLHC>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests through github at 
-L<https://github.com/shantanubhadoria/device-lsm303dlhc/issues>.
+L<https://github.com/shantanubhadoria/perl-device-lsm303dlhc/issues>.
 You will be notified automatically of any progress on your issue.
 
 =head2 Source Code
@@ -110,9 +110,9 @@ You will be notified automatically of any progress on your issue.
 This is open source software.  The code repository is available for
 public review and contribution under the terms of the license.
 
-L<https://github.com/shantanubhadoria/device-lsm303dlhc>
+L<https://github.com/shantanubhadoria/perl-device-lsm303dlhc>
 
-  git clone git://github.com/shantanubhadoria/device-lsm303dlhc.git
+  git clone git://github.com/shantanubhadoria/perl-device-lsm303dlhc.git
 
 =head1 AUTHOR
 
@@ -120,6 +120,8 @@ Shantanu Bhadoria <shantanu at cpan dott org>
 
 =head1 CONTRIBUTORS
 
+=for stopwords Shantanu Bhadoria
+
 =over 4
 
 =item *
@@ -134,7 +136,7 @@ Shantanu Bhadoria <shantanu@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Shantanu Bhadoria.
+This software is copyright (c) 2015 by Shantanu Bhadoria.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
